@@ -465,9 +465,9 @@ recover_data.mcmc = function(object, formula, data, ...) {
     recover_data(cl, trms, NULL, data, ...)
 }
 
-emm_basis.mcmc = function(object, trms, xlev, grid, vcov., ...) {
+emm_basis.mcmc = function(object, trms, xlev, grid, vcov., contrasts.arg = NULL, ...) {
     m = model.frame(trms, grid, na.action = na.pass, xlev = xlev)
-    X = model.matrix(trms, m, contrasts.arg = NULL)
+    X = model.matrix(trms, m, contrasts.arg = contrasts.arg)
     samp = as.matrix(object)[, seq_len(ncol(X)), drop = FALSE]
     bhat = apply(samp, 2, mean)
     if (missing(vcov.))
@@ -487,7 +487,7 @@ recover_data.mcmc.list = function(object, formula, data, ...) {
 }
 
 emm_basis.mcmc.list = function(object, trms, xlev, grid, vcov., ...) {
-    result = emm_basis.mcmc(object[[1]], trms, xlev, grid, vcov, ...)
+    result = emm_basis.mcmc(object[[1]], trms, xlev, grid, vcov., ...)
     cols = seq_len(ncol(result$post.beta))
     for (i in 2:length(object))
         result$post.beta = rbind(result$post.beta, 
@@ -567,14 +567,14 @@ emm_basis.stanreg = function(object, trms, xlev, grid, mode, rescale, ...) {
             X = X[, -xint, drop = FALSE]
         k = length(object$zeta)
         if (mode == "latent") {
-            if (missing(rescale)) 
+            ### if (missing(rescale))  #------ (Disabl rescale)
                 rescale = c(0,1)
             X = rescale[2] * cbind(X, matrix(- 1/k, nrow = nrow(X), ncol = k))
-            bhat = c(bhat, object$zeta - rescale[1] / rescale[2])
+            ### bhat = c(bhat, object$zeta - rescale[1] / rescale[2])
             misc = list(offset.mult = rescale[2])
         }
         else {
-            bhat = c(bhat, object$zeta)
+            ### bhat = c(bhat, object$zeta)
             j = matrix(1, nrow=k, ncol=1)
             J = matrix(1, nrow=nrow(X), ncol=1)
             X = cbind(kronecker(-j, X), kronecker(diag(1,k), J))
@@ -587,6 +587,7 @@ emm_basis.stanreg = function(object, trms, xlev, grid, mode, rescale, ...) {
                 misc$postGridHook = ".clm.postGrid" # we probably need to adapt this
             }
         }
+        nms = colnames(X) = c(nms, names(object$zeta))
         
         misc$respName = as.character.default(terms(object))[2]
     }
